@@ -1,11 +1,15 @@
 import datetime
+import pygame
 import numpy as np
 import math
+import pymunk
 from ev3sim.simulation.interactor import IInteractor
 from ev3sim.simulation.loader import ScriptLoader
 from ev3sim.simulation.world import World, stop_on_pause
 from ev3sim.objects.base import objectFactory
 from ev3sim.visual.manager import ScreenObjectManager
+from ev3sim.visual.utils import screenspace_to_worldspace
+from ev3sim.objects.base import STATIC_CATEGORY
 
 class SoccerInteractor(IInteractor):
 
@@ -16,6 +20,8 @@ class SoccerInteractor(IInteractor):
     BALL_COLLISION_TYPE = 3
     GOAL_COLLISION_TYPE = 4
 
+    _pressed = False
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.names = kwargs.get('names', ['Team 1', 'Team 2'])
@@ -24,6 +30,7 @@ class SoccerInteractor(IInteractor):
         self.show_goal_colliders = kwargs.get('show_goal_colliders', False)
         self.current_goal_score_tick = -1
         self.time_tick = 0
+        self.update_time_text = True
     
     def locateBots(self):
         self.robots = []
@@ -108,6 +115,13 @@ class SoccerInteractor(IInteractor):
         for x in range(len(self.names)):
             ScriptLoader.instance.object_map[f'score{x+1}Text'].text = str(self.team_scores[x])
 
+    def reset(self):
+        self.team_scores = [0 for x in self.names]
+        self.updateScoreText()
+        self.resetPositions()
+        self.time_tick = 0
+        self.update_time_text = True
+
     def resetPositions(self):
         # It is assumed that 2 robots to each team, with indexes increasing as we go across teams.
         for team in range(len(self.names)):
@@ -129,16 +143,29 @@ class SoccerInteractor(IInteractor):
         if self.current_goal_score_tick != -1 and (tick - self.current_goal_score_tick) > self.GOAL_SCORE_PAUSE_DELAY * ScriptLoader.instance.GAME_TICK_RATE:
             self.current_goal_score_tick = -1
             World.instance.paused = False
+
+        # UI Tick
+        if self._pressed:
+            ScriptLoader.instance.object_map["controlsReset"].visual.image_path = 'assets/ui/controls_reset_pressed.png'
+        else:
+            ScriptLoader.instance.object_map["controlsReset"].visual.image_path = 'assets/ui/controls_reset_released.png'
         self.update_time()
 
     @stop_on_pause
     def update_time(self):
         self.time_tick += 1
+        if not self.update_time_text:
+            return
         elapsed = datetime.timedelta(seconds=self.time_tick / ScriptLoader.instance.GAME_TICK_RATE)
         show = self.START_TIME - elapsed
         seconds = show.seconds
         minutes = seconds // 60
         seconds = seconds - minutes * 60
+        # This checks that the timer is completed, and on its final tick.
+        if minutes == 0 and seconds == 0 and (self.time_tick / ScriptLoader.instance.GAME_TICK_RATE == elapsed.seconds):
+            # Pause the game, and make it so that further tick increases don't update the timer text.
+            World.instance.paused = True
+            self.update_time_text = False
         ScriptLoader.instance.object_map['TimerText'].text = '{:02d}:{:02d}'.format(minutes, seconds)
 
     def goalScoredIn(self, teamIndex):
@@ -148,3 +175,30 @@ class SoccerInteractor(IInteractor):
         # Pause the game temporarily
         World.instance.paused = True
         self.current_goal_score_tick = self.cur_tick
+
+    def handleEvent(self, event):
+        if event.type == pygame.MOUSEBUTTONDOWN and event.button == 1:
+            m_pos = screenspace_to_worldspace(event.pos)
+            shapes = World.instance.space.point_query(m_pos, 0.0, pymunk.ShapeFilter(mask=STATIC_CATEGORY))
+            for shape in shapes:
+                for team in range(len(self.names)):
+                    if shape.shape.obj.key.startswith(f'score{team+1}'):
+                        action = shape.shape.obj.key.split(str(team+1))[1]
+                        if action == 'Plus':
+                            self.team_scores[team] += 1
+                        elif action == 'Minus':
+                            if self.team_scores[team] > 0: self.team_scores[team] -= 1
+                        else:
+                            raise ValueError(f"Unknown team action {action}")
+                        self.updateScoreText()
+                if shape.shape.obj.key == "controlsReset":
+                    self._pressed = True
+
+        if event.type == pygame.MOUSEBUTTONUP and event.button == 1:
+            m_pos = screenspace_to_worldspace(event.pos)
+            shapes = World.instance.space.point_query(m_pos, 0.0, pymunk.ShapeFilter(mask=STATIC_CATEGORY))
+            for shape in shapes:
+                if (shape.shape.obj.key == "controlsReset") & self._pressed:
+                    self.reset()
+                self._pressed = False
+            if len(shapes) == 0: self._pressed = False
\ No newline at end of file
