@@ -94,6 +94,9 @@ class IVisualElement:
         """
         raise NotImplementedError(f"The VisualElement {self.__cls__} does not implement the pivotal method `generateShape`")
 
+    def getPositionAnchorOffset(self):
+        return np.array([0., 0.])
+
 class Colorable(IVisualElement):
     _fill: Optional[Tuple[int]]
     _stroke: Optional[Tuple[int]]
@@ -142,6 +145,9 @@ class Image(Colorable):
         self.image_path = kwargs.get('image_path')
         super().initFromKwargs(**kwargs)
         self.fill = kwargs.get('fill', (0, 0, 0, 0))
+        self.hAlignment = kwargs.get('hAlignment', 'm')
+        self.vAlignment = kwargs.get('vAlignment', 'm')
+        self.scale = kwargs.get('scale', 1)
         self.calculatePoints()
 
     @property
@@ -155,18 +161,36 @@ class Image(Colorable):
         self.image = pygame.image.load(self._image_path)
 
     def calculatePoints(self):
-        self.rotated = pygame.transform.rotate(self.image, self.rotation * 180 / np.pi)
+        relative_scale = ScreenObjectManager.instance.relativeScreenScale()
+        new_size = [int(self.image.get_size()[0] * self.scale * relative_scale[0]), int(self.image.get_size()[1] * self.scale * relative_scale[1])]
+        scaled = pygame.transform.scale(self.image, new_size)
+        self.rotated = pygame.transform.rotate(scaled, self.rotation * 180 / np.pi)
         self.rotated.fill(self.fill, special_flags=pygame.BLEND_ADD)
         self.screen_location = utils.worldspace_to_screenspace(self.position)
         self.screen_size = self.rotated.get_size()
-        self.screen_location = (int(self.screen_location[0] - self.screen_size[0] / 2), int(self.screen_location[1] - self.screen_size[1] / 2))
+        if self.hAlignment == 'l':
+            pass
+        elif self.hAlignment == 'm':
+            self.screen_location -= np.array([self.screen_size[0] / 2, 0.0])
+        elif self.hAlignment == 'r':
+            self.screen_location -= np.array([self.screen_size[0], 0.0])
+        else:
+            raise ValueError(f'hAlignment is incorrect: {self.hAlignment}')
+        if self.vAlignment == 't':
+            pass
+        elif self.vAlignment == 'm':
+            self.screen_location -= np.array([0.0, self.screen_size[1] / 2])
+        elif self.vAlignment == 'b':
+            self.screen_location -= np.array([0.0, self.screen_size[1]])
+        else:
+            raise ValueError(f'vAlignment is incorrect: {self.vAlignment}')
         from ev3sim.visual.utils import screenspace_to_worldspace
-        pos_loc = screenspace_to_worldspace(self.screen_location)
+        physics_size = screenspace_to_worldspace([ScreenObjectManager.instance.screen_width / 2 + self.screen_size[0], ScreenObjectManager.instance.screen_height / 2 + self.screen_size[1]])
         self.verts = [
-            screenspace_to_worldspace([ScreenObjectManager.instance.screen_width / 2 + self.screen_size[0]/2, ScreenObjectManager.instance.screen_height / 2 + self.screen_size[1] / 2]),
-            screenspace_to_worldspace([ScreenObjectManager.instance.screen_width / 2 + self.screen_size[0]/2, ScreenObjectManager.instance.screen_height / 2 - self.screen_size[1] / 2]),
-            screenspace_to_worldspace([ScreenObjectManager.instance.screen_width / 2 - self.screen_size[0]/2, ScreenObjectManager.instance.screen_height / 2 - self.screen_size[1] / 2]),
-            screenspace_to_worldspace([ScreenObjectManager.instance.screen_width / 2 - self.screen_size[0]/2, ScreenObjectManager.instance.screen_height / 2 + self.screen_size[1] / 2]),
+            (physics_size[0]/2, physics_size[1]/2),
+            (physics_size[0]/2, -physics_size[1]/2),
+            (-physics_size[0]/2, -physics_size[1]/2),
+            (-physics_size[0]/2, physics_size[1]/2),
         ]
 
     def applyToScreen(self):
@@ -191,6 +215,28 @@ class Image(Colorable):
         shape.filter = pymunk.ShapeFilter(categories=STATIC_CATEGORY if physObj.static else DYNAMIC_CATEGORY)
         return body, shape
 
+    def getPositionAnchorOffset(self):
+        res = np.array([.0, .0])
+        from ev3sim.visual.utils import screenspace_to_worldspace
+        physics_size = screenspace_to_worldspace([ScreenObjectManager.instance.screen_width / 2 + self.screen_size[0], ScreenObjectManager.instance.screen_height / 2 + self.screen_size[1]])
+        if self.hAlignment == 'l':
+            res += np.array([physics_size[0] / 2, 0.0])
+        elif self.hAlignment == 'm':
+            pass
+        elif self.hAlignment == 'r':
+            res -= np.array([physics_size[0] / 2, 0.0])
+        else:
+            raise ValueError(f'hAlignment is incorrect: {self.hAlignment}')
+        if self.vAlignment == 't':
+            res += np.array([0.0, physics_size[1] / 2])
+        elif self.vAlignment == 'm':
+            pass
+        elif self.vAlignment == 'b':
+            res -= np.array([0.0, physics_size[1] / 2])
+        else:
+            raise ValueError(f'vAlignment is incorrect: {self.vAlignment}')
+        return res
+
 class Line(Colorable):
 
     # THESE DON'T HAVE A LOCAL POSITION
@@ -294,12 +340,14 @@ class Circle(Colorable):
             return
         self.point = utils.worldspace_to_screenspace(self.position)
         self.v_radius = int(ScreenObjectManager.instance.screen_height / ScreenObjectManager.instance.map_height * self.radius)
+        self.h_radius = int(ScreenObjectManager.instance.screen_width / ScreenObjectManager.instance.map_width * self.radius)
+        self.rect = pygame.Rect(self.point[0] - self.h_radius, self.point[1] - self.v_radius, self.h_radius * 2, self.v_radius * 2)
 
     def applyToScreen(self):
         if self.fill:
-            pygame.draw.circle(ScreenObjectManager.instance.screen, self.fill, self.point, self.v_radius)
+            pygame.draw.ellipse(ScreenObjectManager.instance.screen, self.fill, self.rect)
         if self.stroke and self.stroke_width:
-            pygame.draw.circle(ScreenObjectManager.instance.screen, self.stroke, self.point, self.v_radius, max(1, int(self.stroke_width * ScreenObjectManager.instance.screen_width / ScreenObjectManager.instance.map_width)))
+            pygame.draw.ellipse(ScreenObjectManager.instance.screen, self.stroke, self.rect, max(1, int(self.stroke_width * ScreenObjectManager.instance.screen_width / ScreenObjectManager.instance.map_width)))
 
     def generateBodyAndShape(self, physObj, body=None, rel_pos=(0, 0)):
         if body is None:
@@ -330,9 +378,11 @@ class Text(Colorable):
 
     def initFromKwargs(self, **kwargs):
         super().initFromKwargs(**kwargs)
-        self.font_style = kwargs.get('font_style', pygame.font.get_default_font())
+        from ev3sim.file_helper import find_abs
+        self.font_style = kwargs.get('font_style', "OpenSans-SemiBold.ttf")
+        self.font_path = find_abs(self.font_style, allowed_areas=['local/assets/', 'local', 'package/assets/', 'package'])
         self.font_size = kwargs.get('font_size', 30)
-        self.font = pygame.freetype.SysFont(self.font_style, self.font_size)
+        self.font = pygame.freetype.Font(self.font_path, self.font_size)
         self.hAlignment = kwargs.get('hAlignment', 'l')
         self.vAlignment = kwargs.get('vAlignment', 't')
         self.text = kwargs.get('text', 'Test')
@@ -341,21 +391,29 @@ class Text(Colorable):
         if not hasattr(self, 'font'):
             return
         self.surface, self.rect = self.font.render(self.text, fgcolor=self.fill)
+        relative_scale = ScreenObjectManager.instance.relativeScreenScale()
+        self.surface = pygame.transform.scale(self.surface, (int(self.surface.get_width() * relative_scale[0]), int(self.surface.get_height() * relative_scale[1])))
+        self.screen_size = (self.surface.get_width(), self.surface.get_height())
+        baseline = np.array([self.rect.x * relative_scale[0], self.rect.y * relative_scale[1]])
+        self.rect.move_ip(-self.rect.x, -self.rect.y)
+        width, height = self.font.get_rect(self.text).width * relative_scale[0], self.font.get_rect(self.text).height * relative_scale[1]
         self.anchor = utils.worldspace_to_screenspace(self.position)
         if self.hAlignment == 'l':
             pass
         elif self.hAlignment == 'm':
-            self.anchor -= np.array([self.font.get_rect(self.text).width / 2.0, 0.0])
+            self.anchor -= np.array([width / 2.0, 0.0])
         elif self.hAlignment == 'r':
-            self.anchor -= np.array([self.font.get_rect(self.text).width, 0.0])
+            self.anchor -= np.array([width, 0.0])
         else:
             raise ValueError(f'hAlignment is incorrect: {self.hAlignment}')
         if self.vAlignment == 't':
-            self.anchor -= np.array([0.0, self.font.get_rect(self.text).height / 2.0])
+            self.anchor -= np.array([0.0, 0.0])
         elif self.vAlignment == 'm':
-            self.anchor -= np.array([0.0, self.font.get_rect(self.text).height])
+            self.anchor -= np.array([0.0, height / 2])
+        elif self.vAlignment == 'baseline':
+            self.anchor -= np.array([0.0, baseline[1]])
         elif self.vAlignment == 'b':
-            self.anchor -= np.array([0.0, 3 * self.font.get_rect(self.text).height / 2.0])
+            self.anchor -= np.array([0.0, height])
         else:
             raise ValueError(f'vAlignment is incorrect: {self.vAlignment}')
         self.rect.move_ip(*self.anchor)
@@ -363,6 +421,28 @@ class Text(Colorable):
     def applyToScreen(self):
         ScreenObjectManager.instance.screen.blit(self.surface, self.rect)
 
+    def getPositionAnchorOffset(self):
+        res = np.array([.0, .0])
+        from ev3sim.visual.utils import screenspace_to_worldspace
+        physics_size = screenspace_to_worldspace([ScreenObjectManager.instance.screen_width / 2 + self.screen_size[0], ScreenObjectManager.instance.screen_height / 2 + self.screen_size[1]])
+        if self.hAlignment == 'l':
+            res += np.array([physics_size[0] / 2, 0.0])
+        elif self.hAlignment == 'm':
+            pass
+        elif self.hAlignment == 'r':
+            res -= np.array([physics_size[0] / 2, 0.0])
+        else:
+            raise ValueError(f'hAlignment is incorrect: {self.hAlignment}')
+        if self.vAlignment == 't':
+            res += np.array([0.0, physics_size[1] / 2])
+        elif self.vAlignment == 'm':
+            pass
+        elif self.vAlignment == 'b':
+            res -= np.array([0.0, physics_size[1] / 2])
+        else:
+            raise ValueError(f'vAlignment is incorrect: {self.vAlignment}')
+        return res
+
 
 def visualFactory(**options):
     if 'name' not in options:
